summaryrefslogtreecommitdiffstats
path: root/qtjava/javalib/org/kde/qt/QTimer.java
diff options
context:
space:
mode:
Diffstat (limited to 'qtjava/javalib/org/kde/qt/QTimer.java')
-rw-r--r--qtjava/javalib/org/kde/qt/QTimer.java36
1 files changed, 18 insertions, 18 deletions
diff --git a/qtjava/javalib/org/kde/qt/QTimer.java b/qtjava/javalib/org/kde/qt/QTimer.java
index b8fd1a74..e07b50ca 100644
--- a/qtjava/javalib/org/kde/qt/QTimer.java
+++ b/qtjava/javalib/org/kde/qt/QTimer.java
@@ -7,7 +7,7 @@ import org.kde.qt.Qt;
*************************************************
$Id$
* Definition of QTimer class
* Created : 931111
@@ -17,7 +17,7 @@ import org.kde.qt.Qt;
* This file may be distributed under the terms of the Q Public License
as defined by Trolltech AS of Norway and appearing in the file
- LICENSE.QPL included in the packaging of this file.
+ LICENSE.TQPL included in the packaging of this file.
* This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
@@ -33,35 +33,35 @@ import org.kde.qt.Qt;
* See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
information about Qt Commercial License Agreements.
- See http://www.trolltech.com/qpl/ for QPL licensing information.
+ See http://www.trolltech.com/qpl/ for TQPL licensing information.
See http://www.trolltech.com/gpl/ for GPL licensing information.
* Contact info@trolltech.com if any conditions of this licensing are
not clear to you.
********************************************** See {@link QTimerSignals} for signals emitted by QTimer
@short $Id: qt/qtimer.
*/
-public class QTimer extends QObject {
- protected QTimer(Class dummy){super((Class) null);}
- public native QMetaObject metaObject();
+public class TQTimer extends TQObject {
+ protected TQTimer(Class dummy){super((Class) null);}
+ public native TQMetaObject metaObject();
public native String className();
- public QTimer(QObject parent, String name) {
+ public TQTimer(TQObject parent, String name) {
super((Class) null);
- newQTimer(parent,name);
+ newTQTimer(parent,name);
}
- private native void newQTimer(QObject parent, String name);
- public QTimer(QObject parent) {
+ private native void newTQTimer(TQObject parent, String name);
+ public TQTimer(TQObject parent) {
super((Class) null);
- newQTimer(parent);
+ newTQTimer(parent);
}
- private native void newQTimer(QObject parent);
- public QTimer() {
+ private native void newTQTimer(TQObject parent);
+ public TQTimer() {
super((Class) null);
- newQTimer();
+ newTQTimer();
}
- private native void newQTimer();
+ private native void newTQTimer();
public native boolean isActive();
public native int start(int msec, boolean sshot);
public native int start(int msec);
@@ -70,8 +70,8 @@ public class QTimer extends QObject {
public native int timerId();
public static native String tr(String arg1, String arg2);
public static native String tr(String arg1);
- public static native void singleShot(int msec, QObject receiver, String member);
- public native boolean event(QEvent arg1);
+ public static native void singleShot(int msec, TQObject receiver, String member);
+ public native boolean event(TQEvent arg1);
/** Deletes the wrapped C++ instance */
protected native void finalize() throws InternalError;
/** Delete the wrapped C++ instance ahead of finalize() */
@@ -7,7 +7,7 @@ import org.kde.qt.Qt;
*************************************************
$Id$
-* Definition of QTimer class
+* Definition of TQTimer class
* Created : 931111
@@ -33,35 +33,35 @@ import org.kde.qt.Qt;
* Contact info@trolltech.com if any conditions of this licensing are
not clear to you.
-********************************************** See {@link QTimerSignals} for signals emitted by QTimer
+********************************************** See {@link TQTimerSignals} for signals emitted by TQTimer
*/